Bifrost: Data Fields

Bifrost

Here is a list of all documented struct and union fields with links to the struct/union documentation for each field:

### - r -

- read() : ColoredCDBG< Unitig_data_t > , CompactedDBG< Unitig_data_t, Graph_data_t > , Kmer , UnitigColors
- read_chunksize : CDBG_Build_opt
- referenceUnitigToString() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- remove() : CompactedDBG< Unitig_data_t, Graph_data_t > , UnitigColors
- rep() : Kmer